Renderbuffers
*************

.. currentmodule:: ModernGL

.. automethod:: Context.renderbuffer(size, components=4, samples=0, floats=True) -> Renderbuffer
	:noindex:

.. automethod:: Context.depth_renderbuffer(size, samples=0) -> Renderbuffer
	:noindex:

.. autoclass:: Renderbuffer
	:members: width, height, size, samples, components, depth

.. toctree::
	:maxdepth: 4
